@@ -58,6 +58,8 @@ class ApacheBase(object):
         else:
             options.setdefault("logformat", "combined")
 
+        options.setdefault("indexes", "off")
+
         # Record a SHA1 of the template we use, so we can detect changes in subsequent runs
         self.options["__hashes_template"] = sha1(open(self.options["template"]).read()).hexdigest()
 
@@ -156,7 +158,7 @@ class Apache(ApacheBase):
                 ssl = "on"
 
         if ssl == "only":
-            opts['ssl'] = 'only'
+            opt['ssl'] = 'only'
         else:
             opt['ssl'] = is_true(ssl)
 
@@ -275,6 +277,9 @@ class ApacheWSGI(ApacheBase):
         else:
             opt['ldapserver'] = None
 
+
+        opt["indexes"] = self.options.get("indexes", "on") in ("on", "yes", "true")
+
         self.write_jinja_config(opt)
 
         self.mkpasswd(opt['protected'])
